==> hoteldruid-mod-ru_3.0.4-1.tar.gz: ru/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Главное меню года"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Добавить новую бронь"; break;
case "prenotazioni del mese di": 		$messaggio = "брони за "; break;
case "visualizza": 				$messaggio = "показать"; break;
case "Gennaio":                               	$messaggio = "Январь"; break;
case "Febbraio":                              	$messaggio = "Февраль"; break;
case "Marzo":                                 	$messaggio = "Март"; break;
case "Aprile":      				$messaggio = "Апрель"; break;
case "Maggio":                           	$messaggio = "Май"; break;
case "Giugno":                            	$messaggio = "Июнь"; break;
case "Luglio":                            	$messaggio = "Июль"; break;
case "Agosto":  				$messaggio = "Август"; break;
case "Settembre":  				$messaggio = "Сентябрь"; break;
case "Ottobre":  				$messaggio = "Октябрь"; break;
case "Novembre":  				$messaggio = "Ноябрь"; break;
case "Dicembre":  				$messaggio = "Декабрь"; break;
case "tabella con":  				$messaggio = "Таблица, содержащая"; break;
case "tutte le prenotazioni":  			$messaggio = "все брони"; break;
case "le spese e le entrate":  			$messaggio = "выручки и платежи"; break;
case "i periodi e le tariffe":  		$messaggio = "периоды и цены"; break;
case "tutti i clienti":  			$messaggio = "все клиенты"; break;
case "le regole di assegnazione":  		$messaggio = "правила назначения"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Добавить нового клиента"; break;
case "Spese ed entrate":  			$messaggio = "Платежи и поступления наличных"; break;
case "disponibilità dal":  			$messaggio = "доступно с"; break;
case "al":  					$messaggio = "до"; break;
case "per":  					$messaggio = "для"; break;
case "persone":	  				$messaggio = "люди"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Добавить или изменить цены"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Добавить или изменить правила назначения"; break;
case "Configura e personalizza":	$messaggio = "Конфигурация и настройки"; break;
case "richiedi l'anno":  			$messaggio = "Перейти к году"; break;
case "vai":  					$messaggio = "Перейти"; break;
case "Non esiste l'anno ":  			$messaggio = "Год "; break;
case " nel database":  				$messaggio = " не существует в базе данных"; break;
case "Crea l'anno":  				$messaggio = "Создать год"; break;
case "Domenica":  				$messaggio = "Воскресенье"; break;
case "Lunedì":  				$messaggio = "Понедельник"; break;
case "Martedì":  				$messaggio = "Вторник"; break;
case "Mercoledì":  				$messaggio = "Среда"; break;
case "Giovedì":  				$messaggio = "Четверг"; break;
case "Venerdì":  				$messaggio = "Пятница"; break;
case "Sabato":	 		 		$messaggio = "Суббота"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "как день начала/конца оплаты"; break;
case "con periodi":  				$messaggio = "используя"; break;
case "settimanali":  				$messaggio = "недельные периоды"; break;
case "giornalieri":  				$messaggio = "суточные периоды проживания"; break;
case "e prenotazioni da":  			$messaggio = "и бронирования с"; break;
case "a":  					$messaggio = "по"; break;
case "anno successivo": 			$messaggio = "следующий год"; break;
case "anni successivi":  			$messaggio = "годами позже"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Импорт из предыдущих ежегодных бронирований, цен (включая дополнительные издержки), пользовательских привилегий и правил назначения."; break;
case "Anno ":  					$messaggio = "Год "; break;
case " creato":  				$messaggio = " создан"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Нет ни одного периодов относительно "; break;
case " nel ":  					$messaggio = " в "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", или день начала/конца отсчета дохода был другой, только данные о дополнительных издержках, депозит, имена цен, пользовательские привилегии и правила назначения 2 и 3 были  импоортированы"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Предупреждение</b></font>: период"; break;
case " finivano dopo quelli del ":  		$messaggio = " закончился после такого же периода от"; break;
case " e vi erano":  				$messaggio = " и там были"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "брони, которые закончились после предела, предоставленного "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", эти бронирования не были импортированы"; break;
case " Do":  					$messaggio = " Вс"; break;
case " Lu":  					$messaggio = " Пн"; break;
case " Ma":  					$messaggio = " Вт"; break;
case " Me":  					$messaggio = " Ср"; break;
case " Gi":  					$messaggio = " Чт"; break;
case " Ve":  					$messaggio = " Пт"; break;
case " Sa":  					$messaggio = " Сб"; break;
case "Gen":  					$messaggio = "Янв"; break;
case "Feb":  					$messaggio = "Фев"; break;
case "Mar":  					$messaggio = "Мар"; break;
case "Apr":  					$messaggio = "Апр"; break;
case "Mag":  					$messaggio = "Май"; break;
case "Giu":  					$messaggio = "Июн"; break;
case "Lug":  					$messaggio = "Июл"; break;
case "Ago":  					$messaggio = "Авг"; break;
case "Set":  					$messaggio = "Сен"; break;
case "Ott":  					$messaggio = "Окт"; break;
case "Nov":  					$messaggio = "Ноя"; break;
case "Dic":  					$messaggio = "Дек"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Формат запрошенного года неверен"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Месяца были неправильно выбраны, они должны идти с января по декабрь"; break;
case "Cognome del cliente":  			$messaggio = "Фамилия клиента"; break;
case "Data iniziale":  				$messaggio = "Дата начала"; break;
case "Data finale":  				$messaggio = "Дата окончания"; break;
case "Tariffa completa":  			$messaggio = "Полная цена"; break;
case "Da pagare":  				$messaggio = "К оплате"; break;
case "Pers":  					$messaggio = "Люди"; break;
case "Registra":  				$messaggio = "Регистрация"; break;
case "Entrata":  				$messaggio = "Регистрация"; break;
case "Uscita":  				$messaggio = "Проверить"; break;
case "Entrata e pagato":  			$messaggio = "Зарегистрировать и оплатить"; break;
case "Uscita e pagato":  			$messaggio = "Проверить и оплатить"; break;
case "mostra tutte le date":  			$messaggio = "показать все даты"; break;
case "Utente":  				$messaggio = "Пользователь"; break;
case "Esci":  					$messaggio = "Выход из системы"; break;
case "Messaggi":  				$messaggio = "Сообщения"; break;
case "dalla":  					$messaggio = "от"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "таблица с периодами и ценами"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "даже без создания нового года"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Нет прав на запись в каталог данных"; break;
case "le statistiche":  			$messaggio = "статистика"; break;
case "inventario e magazzini":  		$messaggio = "инвентарь и кладовые"; break;
case "obsoleti":  				$messaggio = "устарело"; break;
case "Ultimo aggiornamento":  			$messaggio = "Последнее обновление"; break;
case "Aggiorna":  				$messaggio = "обновление"; break;
case "i documenti salvati":  			$messaggio = "сохранённые документы"; break;
case "Punto vendita":  				$messaggio = "Точка продаж"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Нет прав на создание таблиц в базе данных"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Добро пожаловать в HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Выберите язык"; break;
case "crea il database":  			$messaggio = "создать базу данных"; break;
case "Promemoria":  				$messaggio = "Памятка"; break;
case "controlla":  				$messaggio = "check"; break;
case "Anno già creato": 			$messaggio = "Year already created"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-ru_3.0.8-1.tar.gz: ru/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Главное меню года"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Добавить новую бронь"; break;
case "prenotazioni del mese di": 		$messaggio = "брони за "; break;
case "visualizza": 				$messaggio = "показать"; break;
case "Gennaio":                               	$messaggio = "Январь"; break;
case "Febbraio":                              	$messaggio = "Февраль"; break;
case "Marzo":                                 	$messaggio = "Март"; break;
case "Aprile":      				$messaggio = "Апрель"; break;
case "Maggio":                           	$messaggio = "Май"; break;
case "Giugno":                            	$messaggio = "Июнь"; break;
case "Luglio":                            	$messaggio = "Июль"; break;
case "Agosto":  				$messaggio = "Август"; break;
case "Settembre":  				$messaggio = "Сентябрь"; break;
case "Ottobre":  				$messaggio = "Октябрь"; break;
case "Novembre":  				$messaggio = "Ноябрь"; break;
case "Dicembre":  				$messaggio = "Декабрь"; break;
case "tabella con":  				$messaggio = "Таблица, содержащая"; break;
case "tutte le prenotazioni":  			$messaggio = "все брони"; break;
case "le spese e le entrate":  			$messaggio = "выручки и платежи"; break;
case "i periodi e le tariffe":  		$messaggio = "периоды и цены"; break;
case "tutti i clienti":  			$messaggio = "все клиенты"; break;
case "le regole di assegnazione":  		$messaggio = "правила назначения"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Добавить нового клиента"; break;
case "Spese ed entrate":  			$messaggio = "Платежи и поступления наличных"; break;
case "disponibilità dal":  			$messaggio = "доступно с"; break;
case "al":  					$messaggio = "до"; break;
case "per":  					$messaggio = "для"; break;
case "persone":	  				$messaggio = "люди"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Добавить или изменить цены"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Добавить или изменить правила назначения"; break;
case "Configura e personalizza":	$messaggio = "Конфигурация и настройки"; break;
case "richiedi l'anno":  			$messaggio = "Перейти к году"; break;
case "vai":  					$messaggio = "Перейти"; break;
case "Non esiste l'anno ":  			$messaggio = "Год "; break;
case " nel database":  				$messaggio = " не существует в базе данных"; break;
case "Crea l'anno":  				$messaggio = "Создать год"; break;
case "Domenica":  				$messaggio = "Воскресенье"; break;
case "Lunedì":  				$messaggio = "Понедельник"; break;
case "Martedì":  				$messaggio = "Вторник"; break;
case "Mercoledì":  				$messaggio = "Среда"; break;
case "Giovedì":  				$messaggio = "Четверг"; break;
case "Venerdì":  				$messaggio = "Пятница"; break;
case "Sabato":	 		 		$messaggio = "Суббота"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "как день начала/конца оплаты"; break;
case "con periodi":  				$messaggio = "используя"; break;
case "settimanali":  				$messaggio = "недельные периоды"; break;
case "giornalieri":  				$messaggio = "суточные периоды проживания"; break;
case "e prenotazioni da":  			$messaggio = "и бронирования с"; break;
case "a":  					$messaggio = "по"; break;
case "anno successivo": 			$messaggio = "следующий год"; break;
case "anni successivi":  			$messaggio = "годами позже"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Импорт из предыдущих ежегодных бронирований, цен (включая дополнительные издержки), пользовательских привилегий и правил назначения."; break;
case "Anno ":  					$messaggio = "Год "; break;
case " creato":  				$messaggio = " создан"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Нет ни одного периодов относительно "; break;
case " nel ":  					$messaggio = " в "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", или день начала/конца отсчета дохода был другой, только данные о дополнительных издержках, депозит, имена цен, пользовательские привилегии и правила назначения 2 и 3 были  импоортированы"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Предупреждение</b></font>: период"; break;
case " finivano dopo quelli del ":  		$messaggio = " закончился после такого же периода от"; break;
case " e vi erano":  				$messaggio = " и там были"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "брони, которые закончились после предела, предоставленного "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", эти бронирования не были импортированы"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Формат запрошенного года неверен"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Месяца были неправильно выбраны, они должны идти с января по декабрь"; break;
case "Cognome del cliente":  			$messaggio = "Фамилия клиента"; break;
case "Data iniziale":  				$messaggio = "Дата начала"; break;
case "Data finale":  				$messaggio = "Дата окончания"; break;
case "Tariffa completa":  			$messaggio = "Полная цена"; break;
case "Da pagare":  				$messaggio = "К оплате"; break;
case "Pers":  					$messaggio = "Люди"; break;
case "Registra":  				$messaggio = "Регистрация"; break;
case "Entrata":  				$messaggio = "Регистрация"; break;
case "Uscita":  				$messaggio = "Проверить"; break;
case "Entrata e pagato":  			$messaggio = "Зарегистрировать и оплатить"; break;
case "Uscita e pagato":  			$messaggio = "Проверить и оплатить"; break;
case "mostra tutte le date":  			$messaggio = "показать все даты"; break;
case "Utente":  				$messaggio = "Пользователь"; break;
case "Esci":  					$messaggio = "Выход из системы"; break;
case "Messaggi":  				$messaggio = "Сообщения"; break;
case "dalla":  					$messaggio = "от"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "таблица с периодами и ценами"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "даже без создания нового года"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Нет прав на запись в каталог данных"; break;
case "le statistiche":  			$messaggio = "статистика"; break;
case "inventario e magazzini":  		$messaggio = "инвентарь и кладовые"; break;
case "obsoleti":  				$messaggio = "устарело"; break;
case "Ultimo aggiornamento":  			$messaggio = "Последнее обновление"; break;
case "Aggiorna":  				$messaggio = "обновление"; break;
case "i documenti salvati":  			$messaggio = "сохранённые документы"; break;
case "Punto vendita":  				$messaggio = "Точка продаж"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "Нет прав на создание таблиц в базе данных"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Добро пожаловать в HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Выберите язык"; break;
case "crea il database":  			$messaggio = "создать базу данных"; break;
case "Promemoria":  				$messaggio = "Памятка"; break;
case "controlla":  				$messaggio = "check"; break;
case "Anno già creato": 			$messaggio = "Year already created"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "l'anno":  				$messaggio = "year"; break;
case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
